#!/usr/bin/env python3

import json
import csv
import sys
import pathlib


def main(inputfilepath):
    with open(inputfilepath, 'rt', encoding='utf8') as fh:
        data = json.load(fh)

    if not isinstance(data, list):
        print("The json file must hold a list")
        exit()

    keys = None
    for item in data:
        if not isinstance(item, dict):
            print("Each item in the list must be a dict")
            exit()

        if keys is None:
            keys = list(item.keys())
        else:
            if set(item.keys()) != set(keys):
                print("All dicts must have the same keys")
                exit()

    outfilepath = inputfilepath.with_suffix('.csv')

    with open(outfilepath, 'xt', encoding='utf8') as fh:
        writer = csv.DictWriter(fh, keys)
        writer.writeheader()
        for item in data:
            writer.writerow(item)


if len(sys.argv) != 2:
    print("Usage: json2csv.py inputfile.json")
    exit()

main(pathlib.Path(sys.argv[1]))
